@@ -1,14 +1,11 @@
 #' @title Download WFS layer
 #'
 #' @description
-#' Read simple features from IGN Web Feature Service (WFS).
-#' Three minimal info are needed : a location, an apikey
-#' and the name of layer. You can find those information from
-#' [IGN website](https://geoservices.ign.fr/services-web-experts)
+#' Read simple features from IGN Web Feature Service (WFS) from location
+#' and name of layer.
 #'
 #' @usage
 #' get_wfs(x = NULL,
-#'         apikey = NULL,
 #'         layer = NULL,
 #'         filename = NULL,
 #'         spatial_filter = "bbox",
@@ -18,20 +15,17 @@
 #'
 #' @param x Object of class `sf` or `sfc`. Needs to be located in
 #' France.
-#' @param apikey `character`; API key from `get_apikeys()` or directly
-#' from [IGN website](https://geoservices.ign.fr/services-web-experts)
-#' @param layer `character`; name of the layer from `get_layers_metadata(apikey, "wfs")`
+#' @param layer `character`; name of the layer from `get_layers_metadata("wfs")`
 #' or directly from
 #' [IGN website](https://geoservices.ign.fr/services-web-experts)
-#' @param filename Either a character string naming a file or a connection open
+#' @param filename `character`;Either a string naming a file or a connection open
 #' for writing. (ex : "test.shp" or "~/test.shp")
 #' @param spatial_filter `character`; spatial predicate from ECQL language.
 #' See detail and examples for more info.
 #' @param ecql_filter `character`; corresponding to an ECQL query.
 #' See detail and examples for more info.
 #' @param overwrite `logical`; if TRUE, file is overwrite.
-#' @param interactive `character`; if TRUE, no need to specify `apikey`
-#' and `layer`, you'll be ask.
+#' @param interactive `character`; if TRUE, no need to specify `layer`, you'll be ask.
 #'
 #' @return
 #' `sf` object from `sf` package or `NULL` if no data.
@@ -50,15 +44,13 @@
 #' "dwithin", argument can be provide using vector like :
 #' spatial_filter = c("dwithin", distance, units). More info about ECQL language
 #' [here](https://docs.geoserver.org/latest/en/user/filter/ecql_reference.html).
-#' Be aware that "dwithin" is broken and it doesn't accept units properly. Only degrees can be used.
-#' To avoid this, create a buffer and then use "within" instead od "dwithin".
 #' * ECQL query can be provided to `ecql_filter`. This allows direct query of the IGN's WFS
 #' geoservers. If `x` is set, then the `ecql_filter` comes in addition to the
 #' `spatial_filter`. More info for writing ECQL
 #' [here](https://docs.geoserver.org/latest/en/user/tutorials/cql/cql_tutorial.html)
 #'
 #' @seealso
-#' [get_apikeys()], [get_layers_metadata()]
+#' [get_layers_metadata()]
 #'
 #' @examples
 #' \dontrun{
@@ -72,45 +64,39 @@
 #' shape <- get_wfs(x = penmarch,
 #'                  interactive = TRUE)
 #'
-#' # For specific use, choose apikey with get_apikey() and layer with get_layers_metadata()
 #' ## Getting borders of best town in France
-#' apikey <- get_apikeys()[1]
-#' metadata_table <- get_layers_metadata(apikey, "wfs")
+#' metadata_table <- get_layers_metadata("wfs", "administratif")
 #' layer <- metadata_table[32,1] # LIMITES_ADMINISTRATIVES_EXPRESS.LATEST:commune
 #'
 #' # Downloading borders
-#' borders <- get_wfs(penmarch, apikey, layer)
+#' borders <- get_wfs(penmarch, layer)
 #'
 #' # Plotting result
 #' qtm(borders, fill = NULL, borders = "firebrick") # easy map
 #'
 #' # Get forest_area of the best town in France
 #' forest_area <- get_wfs(x = borders,
-#'                        apikey = "environnement",
 #'                        layer = "LANDCOVER.FORESTINVENTORY.V1:resu_bdv1_shape")
 #'
-#' qtm(forest_area, fill = "libelle")
+#' qtm(forest_area, fill = "nom_typn")
 #'
 #' # Using ECQL filters to query IGN server
 #' ## First find attributes of the layer
-#' attrs <- get_wfs_attributes(apikey, layer)
+#' attrs <- get_wfs_attributes(layer)
 #'
 #' ## e.g. : find all commune's name starting by "plou"
 #' plou_borders <- get_wfs(x = NULL, # When x is NULL, all France is query
-#'                         apikey = "administratif",
 #'                         layer = "LIMITES_ADMINISTRATIVES_EXPRESS.LATEST:commune",
 #'                         ecql_filter = "nom_m LIKE 'PLOU%'")
 #' qtm(plou_borders)
 #'
 #' ## Combining ecql_filters
 #' plou_borders_inf_2000 <- get_wfs(x = NULL, # When x is NULL, all France is query
-#'                                  apikey = "administratif",
 #'                                  layer = "LIMITES_ADMINISTRATIVES_EXPRESS.LATEST:commune",
 #'                                  ecql_filter = "nom_m LIKE 'PLOU%' AND population < 2000")
 #' qtm(plou_borders)+ qtm(plou_borders_inf_2000, fill = "red")
 #' }
 get_wfs <- function(x = NULL,
-                    apikey = NULL,
                     layer = NULL,
                     filename = NULL,
                     spatial_filter = "bbox",
@@ -143,10 +129,8 @@ get_wfs <- function(x = NULL,
 
 
    # interactive mode ----
-   # if TRUE menu ask for apikey and layer name
    if (interactive){
-      choice <- interactive_mode()
-      apikey <- choice$apikey
+      choice <- interactive_mode("wfs")
       layer <- choice$layer
    }
 
@@ -154,13 +138,13 @@ get_wfs <- function(x = NULL,
    # When spatial filter "bbox" isn't used, crs are needed
    is_bbox <- sum(spatial_filter == "bbox") == 1
    if(!is_bbox){
-      crs <- get_wfs_default_crs(apikey, layer)
+      crs <- get_wfs_default_crs(layer)
    }
 
    # hit api and loop if there more than 1000 features
-   req <- build_wfs_req(x, apikey, layer, spatial_filter,
+   req <- build_wfs_req(x, layer, spatial_filter,
                         ecql_filter, startindex = 0, crs)
-   resp <- hit_api_wfs(req, ecql_filter, apikey)
+   resp <- hit_api_wfs(req, ecql_filter)
 
    # Succesful request but no feature found
    if (is_empty(resp)){
@@ -174,9 +158,9 @@ get_wfs <- function(x = NULL,
    temp <- resp
    while(nrow(temp) == 1000){
       message("...", appendLF = F)
-      url <- build_wfs_req(x, apikey, layer, spatial_filter,
+      url <- build_wfs_req(x, layer, spatial_filter,
                            ecql_filter, startindex = i, crs)
-      temp <- hit_api_wfs(url, ecql_filter, apikey)
+      temp <- hit_api_wfs(url, ecql_filter)
       resp <- rbind(resp, temp)
       message(nrow(resp), appendLF = F)
       i <- i + 1000
@@ -200,7 +184,6 @@ get_wfs <- function(x = NULL,
 #' @description construct url
 #'
 #' @param x Object of class `sf`. Needs to be located in France.
-#' @param apikey API key from `get_apikeys()`
 #' @param layer Name of the layer
 #' @param spatial_filter See ?get_wfs
 #' @param ecql_filter See ?get_wfs
@@ -209,7 +192,6 @@ get_wfs <- function(x = NULL,
 #' @noRd
 #'
 build_wfs_req <- function(x,
-                          apikey,
                           layer,
                           spatial_filter = NULL,
                           ecql_filter = NULL,
@@ -221,8 +203,7 @@ build_wfs_req <- function(x,
    spatial_predicate <- NULL
 
    if (shape_exist & spatial_filter_exist){
-      spatial_predicate <- construct_spatial_filter(x, spatial_filter,
-                                                    crs, apikey)
+      spatial_predicate <- construct_spatial_filter(x, spatial_filter, crs, layer)
    }
 
    all_filter <- paste(c(spatial_predicate, ecql_filter), collapse = " AND ")
@@ -238,9 +219,8 @@ build_wfs_req <- function(x,
       count = 1000
    )
 
-   request <- request("https://wxs.ign.fr") |>
-      req_url_path_append(apikey) |>
-      req_url_path_append("geoportail/wfs") |>
+   request <- request("https://data.geopf.fr/") |>
+      req_url_path_append("wfs/ows") |>
       req_user_agent("happign (https://paul-carteron.github.io/happign/)") |>
       req_url_query(!!!params) |>
       req_body_form(cql_filter=all_filter)
@@ -251,12 +231,10 @@ build_wfs_req <- function(x,
 #' format url and request it
 #' @param req httr2 request from `build_wfs_req`
 #' @param ecql_filter see `?get_wfs`
-#' @param apikey see `?get_wfs`
 #' @noRd
 #'
 hit_api_wfs <- function(req,
-                        ecql_filter,
-                        apikey) {
+                        ecql_filter) {
 
    tryCatch({
       resp <- req_perform(req) |>
@@ -270,7 +248,6 @@ hit_api_wfs <- function(req,
             stop("Please check that :\n",
                  "- x is not empty ;\n",
                  "- layer is valid by running ",
-                 "`get_layers_metadata(\"", apikey, "\", \"wfs\")`\n",
                  call. = F)
          }})
 
@@ -306,7 +283,6 @@ save_wfs <- function(filename, resp, overwrite, quiet = F){
 #' @param shape object of class sf or sfc
 #' @param spatial_filter list containing spatial operation and other argument
 #' @param crs epsg character from `get_wfs_default_crs`
-#' @param apikey character from `get_apikeys()`
 #' @importFrom sf st_bbox
 #' @return ecql string
 #' @noRd
@@ -314,7 +290,7 @@ save_wfs <- function(filename, resp, overwrite, quiet = F){
 construct_spatial_filter <- function(x = NULL,
                                      spatial_filter = NULL,
                                      crs = NULL,
-                                     apikey = NULL){
+                                     layer = NULL){
 
    # Test for units
    units <- c("feet", "meters", "statute miles", "nautical miles", "kilometers")
@@ -341,7 +317,13 @@ construct_spatial_filter <- function(x = NULL,
    # Build final spatial filter
    spatial_filter <- sprintf("%s(%s, %s)",
                              toupper(spatial_filter[1]),
-                             ifelse(apikey == "topographie", "geometrie", "the_geom"),
+                             if (grepl("BDTOPO", layer)){
+                                "geometrie"
+                             }else if (grepl("DFCI", layer)){
+                                "the_geom"
+                             }else{
+                                "geom"
+                             },
                              paste(c(geom, spatial_filter[-1]), collapse = ", "))
 
    return(spatial_filter)
